@@ -24,6 +24,7 @@
 #include "config.h"
 
 #include "pango-fontmap.h"
+#include "pango-fontset.h"
 #include "pangocoretext-private.h"
 #include "pango-impl-utils.h"
 
@@ -1695,11 +1696,8 @@ static PangoFont *
 pango_core_text_fontset_load_font (PangoCoreTextFontset *ctfontset,
                                    CTFontDescriptorRef   ctdescriptor)
 {
-  PangoCoreTextFontsetKey *key;
   PangoCoreTextFont *font;
 
-  key = pango_core_text_fontset_get_key (ctfontset);
-
   /* For now, we will default the fallbacks to not have synthetic italic,
    * in the future this may be improved.
    */
@@ -1774,7 +1772,7 @@ pango_core_text_fontset_finalize (GObject *object)
     {
       PangoCoverage *coverage = g_ptr_array_index (ctfontset->coverages, i);
       if (coverage)
-        pango_coverage_unref (coverage);
+        g_object_unref (coverage);
     }
   g_ptr_array_free (ctfontset->coverages, TRUE);
 
